summaryrefslogtreecommitdiff
path: root/cpu
diff options
context:
space:
mode:
Diffstat (limited to 'cpu')
-rw-r--r--cpu/static_inst.hh6
1 files changed, 3 insertions, 3 deletions
diff --git a/cpu/static_inst.hh b/cpu/static_inst.hh
index 343a3d9b7..644c7dfc4 100644
--- a/cpu/static_inst.hh
+++ b/cpu/static_inst.hh
@@ -43,7 +43,7 @@
class ExecContext;
class SpecExecContext;
class SimpleCPU;
-class CPU;
+class FullCPU;
class DynInst;
class SymbolTable;
@@ -295,9 +295,9 @@ class StaticInst : public StaticInstBase
Trace::InstRecord *traceData) = 0;
/**
* Execute this instruction under detailed CPU model.
*/
- virtual Fault execute(CPU *cpu, SpecExecContext *xc, DynInst *dynInst,
+ virtual Fault execute(FullCPU *cpu, SpecExecContext *xc, DynInst *dynInst,
Trace::InstRecord *traceData) = 0;
/**
@@ -295,9 +295,9 @@ class StaticInst : public StaticInstBase
Trace::InstRecord *traceData) = 0;
/**
- * Execute this instruction under detailed CPU model.
+ * Execute this instruction under detailed FullCPU model.
*/